---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:2003-07-29;229
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20030825&codiceRedaz=003G0223&dataVigenza=20251104
dataGU: 20030825
codiceRedaz: 003G0223
dataVigenza: 20251104
---

# Interventi in materia di qualita' della regolazione, riassetto
normativo e codificazione. - Legge di semplificazione 2001.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

Promulga la seguente legge:

## NUOVA DISCIPLINA IN MATERIA DI SEMPLIFICAZIONE E RIASSETTO NORMATIVO

### Art. 1. - (Riassetto normativo e codificazione).

1. L'articolo 20 della legge 15 marzo 1997, n. 59, e successive modificazioni, e' sostituito dal seguente: "ART. 20. - 1. Il Governo, sulla base di un programma di priorita' di interventi, definito, con deliberazione del Consiglio dei ministri, in relazione alle proposte formulate dai Ministri competenti, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, entro la data del 30 aprile, presenta al Parlamento, entro il 31 maggio di ogni anno, un disegno di legge per la semplificazione e il riassetto normativo, volto a definire, per l'anno successivo, gli indirizzi, i criteri, le modalita' e le materie di intervento, anche ai fini della ridefinizione dell'area di incidenza delle pubbliche funzioni con particolare riguardo all'assetto delle competenze dello Stato, delle regioni e degli enti locali. In allegato al disegno di legge e' presentata una relazione sullo stato di attuazione della semplificazione e del riassetto. 2. Il disegno di legge di cui al comma 1 prevede l'emanazione di decreti legislativi, relativamente alle norme legislative sostanziali e procedimentali, nonche' di regolamenti ai sensi dell'articolo 17, commi 1 e 2, della legge 23 agosto 1988, n. 400, e successive modificazioni, per le norme regolamentari di competenza dello Stato. 3. Salvi i principi e i criteri direttivi specifici per le singole materie, stabiliti con la legge annuale di semplificazione e riassetto normativo, l'esercizio delle deleghe legislative di cui ai commi 1 e 2 si attiene ai seguenti principi e criteri direttivi: a) definizione del riassetto normativo e codificazione della normativa primaria regolante la materia, previa acquisizione del parere del Consiglio di Stato, reso nel termine di novanta giorni dal ricevimento della richiesta, con determinazione dei principi fondamentali nelle materie di legislazione concorrente; b) indicazione esplicita delle norme abrogate, fatta salva l'applicazione dell'articolo 15 delle disposizioni sulla legge in generale premesse al codice civile; c) indicazione dei principi generali, in particolare per quanto attiene alla informazione, alla partecipazione, al contraddittorio, alla trasparenza e pubblicita' che regolano i procedimenti amministrativi ai quali si attengono i regolamenti previsti dal comma 2 del presente articolo, nell'ambito dei principi stabiliti dalla legge 7 agosto 1990, n. 241, e successive modificazioni; d) eliminazione degli interventi amministrativi autorizzatori e delle misure di condizionamento della liberta' contrattuale, ove non vi contrastino gli interessi pubblici alla difesa nazionale, all'ordine e alla sicurezza pubblica, all'amministrazione della giustizia, alla regolazione dei mercati e alla tutela della concorrenza, alla salvaguardia del patrimonio culturale e dell'ambiente, all'ordinato assetto del territorio, alla tutela dell'igiene e della salute pubblica; e) sostituzione degli atti di autorizzazione, licenza, concessione, nulla osta, permesso e di consenso comunque denominati che non implichino esercizio di discrezionalita' amministrativa e il cui rilascio dipenda dall'accertamento dei requisiti e presupposti di legge, con una denuncia di inizio di attivita' da presentare da parte dell'interessato all'amministrazione competente corredata dalle attestazioni e dalle certificazioni eventualmente richieste; f) determinazione dei casi in cui le domande di rilascio di un atto di consenso, comunque denominato, che non implichi esercizio di discrezionalita' amministrativa, corredate dalla documentazione e dalle certificazioni relative alle caratteristiche tecniche o produttive dell'attivita' da svolgere, eventualmente richieste, si considerano accolte qualora non venga comunicato apposito provvedimento di diniego entro il termine fissato per categorie di atti in relazione alla complessita' del procedimento, con esclusione, in ogni caso, dell'equivalenza tra silenzio e diniego o rifiuto; g) revisione e riduzione delle funzioni amministrative non direttamente rivolte: 1) alla regolazione ai fini dell'incentivazione della concorrenza; 2) alla eliminazione delle rendite e dei diritti di esclusivita', anche alla luce della normativa comunitaria; 3) alla eliminazione dei limiti all'accesso e all'esercizio delle attivita' economiche e lavorative; 4) alla protezione di interessi primari, costituzionalmente rilevanti, per la realizzazione della solidarieta' sociale; 5) alla tutela dell'identita' e della qualita' della produzione tipica e tradizionale e della professionalita'; h) promozione degli interventi di autoregolazione per standard qualitativi e delle certificazioni di conformita' da parte delle categorie produttive, sotto la vigilanza pubblica o di organismi indipendenti, anche privati, che accertino e garantiscano la qualita' delle fasi delle attivita' economiche e professionali, nonche' dei processi produttivi e dei prodotti o dei servizi; i) per le ipotesi per le quali sono soppressi i poteri amministrativi autorizzatori o ridotte le funzioni pubbliche condizionanti l'esercizio delle attivita' private, previsione dell'autoconformazione degli interessati a modelli di regolazione, nonche' di adeguati strumenti di verifica e controllo successivi. I modelli di regolazione vengono definiti dalle amministrazioni competenti in relazione all'incentivazione della concorrenzialita', alla riduzione dei costi privati per il rispetto dei parametri di pubblico interesse, alla flessibilita' dell'adeguamento dei parametri stessi alle esigenze manifestatesi nel settore regolato; l) attribuzione delle funzioni amministrative ai comuni, salvo il conferimento di funzioni a province, citta' metropolitane, regioni e Stato al fine di assicurarne l'esercizio unitario in base ai principi di sussidiarieta', differenziazione e adeguatezza; determinazione dei principi fondamentali di attribuzione delle funzioni secondo gli stessi criteri da parte delle regioni nelle materie di competenza legislativa concorrente; m) definizione dei criteri di adeguamento dell'organizzazione amministrativa alle modalita' di esercizio delle funzioni di cui al presente comma; n) indicazione esplicita dell'autorita' competente a ricevere il rapporto relativo alle sanzioni amministrative, ai sensi dell'articolo 17 della legge 24 novembre 1981, n. 689. 4. I decreti legislativi e i regolamenti di cui al comma 2, emanati sulla base della legge di semplificazione e riassetto normativo annuale, per quanto concerne le funzioni amministrative mantenute, si attengono ai seguenti principi: a) semplificazione dei procedimenti amministrativi, e di quelli che agli stessi risultano strettamente connessi o strumentali, in modo da ridurre il numero delle fasi procedimentali e delle amministrazioni intervenienti, anche riordinando le competenze degli uffici, accorpando le funzioni per settori omogenei, sopprimendo gli organi che risultino superflui e costituendo centri interservizi dove ricollocare il personale degli organi soppressi e raggruppare competenze diverse ma confluenti in un'unica procedura, nel rispetto dei principi generali indicati ai sensi del comma 3, lettera c), e delle competenze riservate alle regioni; b) riduzione dei termini per la conclusione dei procedimenti e uniformazione dei tempi di conclusione previsti per procedimenti tra loro analoghi; c) regolazione uniforme dei procedimenti dello stesso tipo che si svolgono presso diverse amministrazioni o presso diversi uffici della medesima amministrazione; d) riduzione del numero di procedimenti amministrativi e accorpamento dei procedimenti che si riferiscono alla medesima attivita'; e) semplificazione e accelerazione delle procedure di spesa e contabili, anche mediante l'adozione di disposizioni che prevedano termini perentori, prorogabili per una sola volta, per le fasi di integrazione dell'efficacia e di controllo degli atti, decorsi i quali i provvedimenti si intendono adottati; f) adeguamento delle procedure alle nuove tecnologie informatiche. 5. I decreti legislativi di cui al comma 2 sono emanati su proposta del Ministro competente, di concerto con il Presidente del Consiglio dei ministri o il Ministro per la funzione pubblica, con i Ministri interessati e con il Ministro dell'economia e delle finanze, previa acquisizione del parere della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e, successivamente, dei pareri delle Commissioni parlamentari competenti che sono resi entro il termine di sessanta giorni dal ricevimento della richiesta. 6. I regolamenti di cui al comma 2 sono emanati con decreto del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Presidente del Consiglio dei ministri o del Ministro per la funzione pubblica, di concerto con il Ministro competente, previa acquisizione del parere della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, quando siano coinvolti interessi delle regioni e delle autonomie locali, del parere del Consiglio di Stato nonche' delle competenti Commissioni parlamentari. I pareri della Conferenza unificata e del Consiglio di Stato sono resi entro novanta giorni dalla richiesta; quello delle Commissioni parlamentari e' reso, successivamente ai precedenti, entro sessanta giorni dalla richiesta. Per la predisposizione degli schemi di regolamento la Presidenza del Consiglio dei ministri, ove necessario, promuove, anche su richiesta del Ministro competente, riunioni tra le amministrazioni interessate. Decorsi sessanta giorni dalla richiesta di parere alle Commissioni parlamentari, i regolamenti possono essere comunque emanati. 7. I regolamenti di cui al comma 2, ove non diversamente previsto dai decreti legislativi, entrano in vigore il quindicesimo giorno successivo alla data della loro pubblicazione nella Gazzetta Ufficiale. Con effetto dalla stessa data sono abrogate le norme, anche di legge, regolatrici dei procedimenti. 8. I regolamenti di cui al comma 2 si conformano, oltre ai principi di cui al comma 4, ai seguenti criteri e principi: a) trasferimento ad organi monocratici o ai dirigenti amministrativi di funzioni anche decisionali, che non richiedono, in ragione della loro specificita', l'esercizio in forma collegiale, e sostituzione degli organi collegiali con conferenze di servizi o con interventi, nei relativi procedimenti, dei soggetti portatori di interessi diffusi; b) individuazione delle responsabilita' e delle procedure di verifica e controllo; c) soppressione dei procedimenti che risultino non piu' rispondenti alle finalita' e agli obiettivi fondamentali definiti dalla legislazione di settore o che risultino in contrasto con i principi generali dell'ordinamento giuridico nazionale o comunitario; d) soppressione dei procedimenti che comportino, per l'amministrazione e per i cittadini, costi piu' elevati dei benefici conseguibili, anche attraverso la sostituzione dell'attivita' amministrativa diretta con forme di autoregolamentazione da parte degli interessati, prevedendone comunque forme di controllo; e) adeguamento della disciplina sostanziale e procedimentale dell'attivita' e degli atti amministrativi ai principi della normativa comunitaria, anche sostituendo al regime concessorio quello autorizzatorio; f) soppressione dei procedimenti che derogano alla normativa procedimentale di carattere generale, qualora non sussistano piu' le ragioni che giustifichino una difforme disciplina settoriale; g) regolazione, ove possibile, di tutti gli aspetti organizzativi e di tutte le fasi del procedimento. 9. I Ministeri sono titolari del potere di iniziativa della semplificazione e del riassetto normativo nelle materie di loro competenza, fatti salvi i poteri di indirizzo e coordinamento della Presidenza del Consiglio dei ministri, che garantisce anche l'uniformita' e l'omogeneita' degli interventi di riassetto e semplificazione. La Presidenza del Consiglio dei ministri garantisce, in caso di inerzia delle amministrazioni competenti, l'attivazione di specifiche iniziative di semplificazione e di riassetto normativo. 10. Gli organi responsabili di direzione politica e di amministrazione attiva individuano forme stabili di consultazione e di partecipazione delle organizzazioni di rappresentanza delle categorie economiche e produttive e di rilevanza sociale, interessate ai processi di regolazione e di semplificazione. 11. I servizi di controllo interno compiono accertamenti sugli effetti prodotti dalle norme contenute nei regolamenti di semplificazione e di accelerazione dei procedimenti amministrativi e possono formulare osservazioni e proporre suggerimenti per la modifica delle norme stesse e per il miglioramento dell'azione amministrativa".

2. Le disposizioni di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dal presente articolo, si applicano anche alle deleghe legislative in materia di semplificazione e riassetto normativo conferite con leggi approvate dal Parlamento nel corso della presente legislatura prima della data di entrata in vigore della presente legge.

### Art. 2. - Riassetto normativo in materia di produzione normativa, di semplificazione e di qualita' della regolazione

1. Il Governo e' delegato ad adottare, entro (( due anni )) dalla data di entrata in vigore della presente legge, un decreto legislativo, su proposta del Presidente del Consiglio dei ministri, sentita la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, per il riassetto delle disposizioni statali di natura legislativa vigenti in materia di produzione normativa, semplificazione e qualita' della regolazione, ai sensi e secondo i principi e criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) garanzia della coerenza giuridica, logica e sistematica della normativa, adeguamento, aggiornamento e semplificazione del linguaggio normativo;
- b) ricorso al riassetto normativo per materie e alla riduzione delle disposizioni legislative vigenti, anche mediante apposite leggi periodiche contenenti l'indicazione delle disposizioni abrogate o comunque non piu' in vigore;
- c) delegificazione delle norme di legge concernenti gli aspetti organizzativi e procedimentali, secondo i criteri previsti dall'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge;
- d) definizione delle funzioni e dei compiti della Presidenza del Consiglio dei ministri, in armonia con quanto disposto dalla legge 23 agosto 1988, n. 400, e successive modificazioni, dal decreto legislativo 30 luglio 1999, n. 303, e successive modificazioni, dalla legge 15 marzo 1997, n. 59, e successive modificazioni, dalla legge 8 marzo 1999, n. 50, e dalle leggi annuali di semplificazione e ferme restando le competenze dei Ministeri di settore;
- e) coordinamento con l'attivita' consultiva del Consiglio di Stato, anche ai fini di adeguamento delle strutture organizzative, ai sensi degli articoli 14 e 16 del testo unico delle leggi sul Consiglio di Stato, di cui al regio decreto 26 giugno 1924, n. 1054, e dell'articolo 17, commi 25, 27 e 28, della legge 15 maggio 1997, n. 127;
- f) previsione e definizione di procedure di verifica dell'impatto regolatorio, ai sensi delle direttive del Presidente del Consiglio dei ministri in materia di analisi tecnico-normativa e di analisi dell'impatto della regolamentazione, anche a seguito di un congruo periodo di applicazione delle norme, con adeguati strumenti di informazione e partecipazione degli utenti e delle categorie interessate.

2. Con regolamento di cui all'articolo 17, comma 1, della legge 23 agosto 1988, n. 400, e successive modificazioni, sono emanate norme di attuazione ed esecuzione del decreto legislativo di cui al comma 1.

3. Nell'ambito della Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, il Governo acquisisce indirizzi e proposte nella materia della qualita' della regolazione e osservazioni per l'adozione di strumenti comuni.

4. Il decreto legislativo di cui al comma 1 e' emanato previo parere delle Commissioni parlamentari competenti reso entro il termine di sessanta giorni dal ricevimento della richiesta.

### Art. 3. - Riassetto normativo in materia di sicurezza del lavoro

1. Il Governo e' delegato ad adottare, (( entro il 30 giugno 2005 )), uno o piu' decreti legislativi per il riassetto delle disposizioni vigenti in materia di sicurezza e tutela della salute dei lavoratori, ai sensi e secondo i principi e criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) riordino, coordinamento, armonizzazione e semplificazione delle disposizioni vigenti per l'adeguamento alle normative comunitarie e alle convenzioni internazionali in materia;
- b) determinazione di misure tecniche ed amministrative di prevenzione compatibili con le caratteristiche gestionali ed organizzative delle imprese, in particolare di quelle artigiane e delle piccole imprese, anche agricole, forestali e zootecniche;
- c) riordino delle norme tecniche di sicurezza delle macchine e degli istituti concernenti l'omologazione, la certificazione e l'autocertificazione;
- d) riformulazione dell'apparato sanzionatorio, con riferimento, in particolare, alle fattispecie contravvenzionali a carico dei preposti, alla previsione di sanzioni amministrative per gli adempimenti formali di carattere documentale; alla revisione del regime di responsabilita' tenuto conto della posizione gerarchica all'interno dell'impresa e dei poteri in ordine agli adempimenti in materia di prevenzione sui luoghi di lavoro; al coordinamento delle funzioni degli organi preposti alla programmazione, alla vigilanza ed al controllo, qualificando prioritariamente i compiti di prevenzione e di informazione rispetto a quelli repressivi e sanzionatori;
- e) promozione dell'informazione e della formazione preventiva e periodica dei lavoratori sui rischi connessi all'attivita' dell'impresa in generale e allo svolgimento delle proprie mansioni, con particolare riguardo ai pericoli derivanti dall'esposizione a rumore, ad agenti chimici, fisici, biologici, cancerogeni e ad altre sostanze o preparati pericolosi o nocivi e alle misure di prevenzione da adottare in relazione ai rischi;
- f) assicurazione della tutela della salute e della sicurezza sul lavoro in tutti i settori di attivita', pubblici e privati, e a tutti i lavoratori, indipendentemente dal tipo di contratto stipulato con il datore di lavoro o con il committente;
- g) adeguamento del sistema prevenzionistico e del relativo campo di applicazione alle nuove forme di lavoro e tipologie contrattuali, anche in funzione di contrasto rispetto al fenomeno del lavoro sommerso e irregolare;
- h) promozione di codici di condotta e diffusione di buone prassi che orientino la condotta dei datori di lavoro, dei lavoratori e di tutti i soggetti interessati;
- i) riordino e razionalizzazione delle competenze istituzionali al fine di evitare sovrapposizioni e duplicazioni di interventi e competenze, garantendo indirizzi generali uniformi su tutto il territorio nazionale nel rispetto delle competenze previste dall'articolo 117 della Costituzione;
- l) realizzazione delle condizioni per una adeguata informazione e formazione di tutti i soggetti impegnati nell'attivita' di prevenzione e per la circolazione di tutte le informazioni rilevanti per l'elaborazione e l'attuazione delle misure di sicurezza necessarie;
- m) modifica o integrazione delle discipline vigenti per i singoli settori interessati, per evitare disarmonie;
- n) esclusione di qualsiasi onere finanziario per il lavoratore in relazione all'adozione delle misure relative alla sicurezza, all'igiene e alla tutela della salute dei lavoratori.

### Art. 4. - Riassetto in materia di assicurazioni

1. Il Governo e' delegato ad adottare, entro due anni dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi per il riassetto delle disposizioni vigenti in materia di assicurazioni, ai sensi e secondo i principi e criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) adeguamento della normativa alle disposizioni comunitarie e agli accordi internazionali;
- b) tutela dei consumatori e, in generale, dei contraenti piu' deboli, sotto il profilo della trasparenza delle condizioni contrattuali, nonche' dell'informativa preliminare, contestuale e successiva alla conclusione del contratto, avendo riguardo anche alla correttezza dei messaggi pubblicitari e del processo di liquidazione dei sinistri, compresi gli aspetti strutturali di tale servizio;
- c) salvaguardia dell'effettiva concorrenza tra le imprese autorizzate all'esercizio dell'attivita' assicurativa in Italia o operanti in regime di liberta' di prestazioni di servizi;
- d) previsione di specifici requisiti di accesso e di esercizio per le societa' di mutua assicurazione esonerate dal pieno rispetto delle norme comunitarie, nonche' per le imprese di riassicurazione;
- e) garanzia di una corretta gestione patrimoniale e finanziaria delle imprese autorizzate all'esercizio dell'attivita' assicurativa, anche nell'ipotesi di una loro appartenenza ad un gruppo assicurativo, nonche' con riferimento alle partecipazioni di imprese assicurative in soggetti esercenti attivita' connesse a quella assicurativa e di partecipazione di questi ultimi in imprese assicurative;
- f) armonizzazione della disciplina delle diverse figure di intermediari nell'attivita' di distribuzione dei servizi assicurativi, compresi i soggetti che, per conto di intermediari, svolgono questa attivita' nei confronti del pubblico;
- g) armonizzazione della disciplina sull'esercizio e sulla vigilanza delle imprese di assicurazione e degli intermediari assicurativi alla normativa comunitaria;
- h) riformulazione dell'apparato sanzionatorio alla luce dei principi generali in materia: 1) affiancando alle ipotesi di ricorso alla sanzione amministrativa pecuniaria nei riguardi di imprese e operatori del settore, la previsione di specifiche sanzioni penali, modulate tra limiti minimi e massimi, nei casi di abusivo esercizio di attivita' assicurativa, agenziale, mediatizia e peritale da parte di imprese e soggetti non autorizzati o non iscritti ai previsti albi e ruoli ovvero di rifiuto di accesso, opposto ai funzionari dell'Istituto per la vigilanza sulle assicurazioni private e di interesse collettivo (ISVAP), agli uffici o alla documentazione relativa alle anzidette attivita', anche esercitate in via di fatto o, infine, di truffa assicurativa; ((1-bis) raddoppiando la misura delle sanzioni penali e quintuplicando la misura massima delle sanzioni amministrative pecuniarie determinate in una somma di denaro, ad eccezione delle sanzioni previste dalla legge 12 agosto 1982, n. 576, e successive modificazioni.)) 2) prevedendo la facolta' di difesa in giudizio da parte dell'ISVAP, a mezzo dei suoi funzionari, nei ricorsi contro i provvedimenti sanzionatori di cui all'articolo 6 della legge 5 marzo 2001, n. 57;
- i) riassetto della disciplina dei rapporti tra l'ISVAP e il Governo, in ordine alle procedure di crisi cui sono assoggettate le imprese di assicurazione.

### Art. 5. - Riassetto in materia di incentivi alle attivita' produttive

1. Il Governo e' delegato ad adottare, entro (( due anni )) dalla data di entrata in vigore della presente legge, un decreto legislativo per il riassetto delle disposizioni vigenti in materia di interventi di sostegno pubblico per lo sviluppo delle attivita' produttive, ai sensi e secondo i principi e criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) articolazione delle disposizioni allo scopo di renderle strumenti coordinati per il raggiungimento degli obiettivi di politica industriale fissati dal Governo e dal Parlamento con l'approvazione del Documento di programmazione economico-finanziaria, anche in base ai diversi inquadramenti degli aiuti previsti dalla normativa dell'Unione europea e nel rispetto dell'articolo 117 della Costituzione;
- b) limitazione della normativa primaria alla individuazione dei soli requisiti sostanziali per la concessione degli incentivi nel rispetto dei limiti previsti dall'articolo 87 del trattato che istituisce la Comunita' europea;
- c) delegificazione e rinvio alla normazione regolamentare dello Stato e alla normazione regionale, secondo le rispettive competenze, della disciplina dei procedimenti amministrativi secondo i criteri di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, nonche' i principi contenuti nel decreto legislativo 31 marzo 1998, n. 123, e successive modificazioni;
- d) definizione, tra i principi fondamentali per la legislazione regionale, della priorita' di intervento a favore delle attivita' produttive situate nelle aree territoriali meno sviluppate e nelle zone montane, del raccordo tra i diversi strumenti di incentivazione anche di carattere fiscale, della previsione di procedure semplificate per le imprese artigiane e le piccole e medie imprese.

### Art. 6. - Riassetto in materia di prodotti alimentari

1. Il Governo e' delegato ad adottare, entro (( quattro anni )) dalla data di entrata in vigore della presente legge, un decreto legislativo per il riassetto delle disposizioni vigenti in materia di prodotti alimentari, ai sensi e secondo i principi e criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) armonizzazione della disciplina della produzione e della commercializzazione dei prodotti alimentari ai principi e alle norme di diritto comunitario, con particolare riferimento alla libera circolazione, allo scopo di assicurare competitivita' alle imprese;
- b) tutela degli interessi relativi alla salute, all'ambiente, alla protezione del consumatore e alla qualita' dei prodotti, alla salute degli animali e vegetali;
- c) abrogazione o modificazione delle norme rese inapplicabili o superate dallo sviluppo tecnologico e non piu' adeguate all'evoluzione produttiva e commerciale delle imprese, fermo restando il diritto dei consumatori all'informazione;
- d) fissazione di regole uniformi per cio' che concerne il sistema sanzionatorio e le modalita' di controllo e di vigilanza, salvo per i prodotti oggetto di specifica normativa comunitaria, e in particolare per il prelevamento dei campioni;
- e) semplificazione delle procedure esistenti, eliminando quelle che pongono a carico delle aziende oneri non prescritti, per gli stessi prodotti, in altri Stati membri dell'Unione europea;
- f) distinzione tra norme di produzione e di commercializzazione, con particolare riferimento agli aspetti tecnici e merceologici, norme concernenti il controllo dei prodotti, norme concernenti la istituzione di un unico sistema sanzionatorio.

### Art. 7. - Riassetto in materia di tutela dei consumatori

1. Il Governo e' delegato ad adottare, entro (( ventiquattro mesi )) dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi, per il riassetto delle disposizioni vigenti in materia di tutela dei consumatori ai sensi e secondo i principi e i criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) adeguamento della normativa alle disposizioni comunitarie e agli accordi internazionali e articolazione della stessa allo scopo di armonizzarla e riordinarla, nonche' di renderla strumento coordinato per il raggiungimento degli obiettivi di tutela del consumatore previsti in sede internazionale;
- b) omogeneizzazione delle procedure relative al diritto di recesso del consumatore nelle diverse tipologie di contratto;
- c) conclusione, in materia di contratti a distanza, del regime di vigenza transitoria delle disposizioni piu' favorevoli per i consumatori, previste dall'articolo 15 del decreto legislativo 22 maggio 1999, n. 185, di attuazione della direttiva 97/7/CE del Parlamento europeo e del Consiglio, del 20 maggio 1997, e rafforzamento della tutela del consumatore in materia di televendite;
- d) coordinamento, nelle procedure di composizione extragiudiziale delle controversie, dell'intervento delle associazioni dei consumatori, nel rispetto delle raccomandazioni della Commissione delle Comunita' europee.

### Art. 8. - Riassetto in materia di metrologia legale

1. Il Governo e' delegato ad adottare, entro ((ventiquattro mesi)) dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi, per il riassetto delle disposizioni vigenti in materia di metrologia legale ai sensi e secondo i principi e i criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) riordino e adeguamento della normativa in relazione ai mutamenti intervenuti nel mercato, all'evoluzione del progresso tecnologico e al nuovo assetto di competenze derivato dal trasferimento di funzioni alle camere di commercio, industria, artigianato e agricoltura in applicazione del decreto legislativo 31 marzo 1998, n. 112, e successive modificazioni;
- b) semplificazione e deregolamentazione degli adempimenti amministrativi per gli operatori del settore;
- c) armonizzazione della disciplina con le raccomandazioni e le indicazioni dell'Unione europea e degli organismi internazionali sui pesi e sulle misure.

### Art. 9. - Riassetto in materia di internazionalizzazione delle imprese

1. Il Governo e' delegato ad adottare, entro (( trenta mesi )) dalla data di entrata in vigore della presente legge, un decreto legislativo recante norme per il riassetto delle disposizioni vigenti in materia di internazionalizzazione delle imprese, ai sensi e secondo i principi e i criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) riunire e coordinare tutte le disposizioni legislative in materia di internazionalizzazione delle imprese, considerando, oltre alle esportazioni, anche gli investimenti in grado di promuovere l'internazionalizzazione delle produzioni italiane, prevedendo la delegificazione dei procedimenti in materia;
- b) coordinare le misure di intervento di competenza dello Stato con quelle delle regioni e degli altri soggetti operanti nel settore dell'internazionalizzazione delle imprese;
- c) prevedere accordi tra enti pubblici e il sistema bancario per l'utilizzo dei servizi e delle sedi estere degli istituti di credito.

((

1-bis. Il Governo e' altresi' delegato ad adottare, entro trenta mesi dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi ai fini della ridefinizione, del riordino e della razionalizzazione degli enti operanti nel settore dell'internazionalizzazione delle imprese.

1-ter. I decreti legislativi di cui al comma 1-bis, nel rispetto e in coerenza con la legislazione comunitaria, realizzano il necessario coordinamento con le altre disposizioni vigenti in materia di promozione e di finanziamento dell'internazionalizzazione delle im-prese secondo i seguenti principi e criteri direttivi:

- a) rispetto dei compiti attribuiti al Ministero delle attivita' produttive, al Ministero degli affari esteri e al Ministero dell'economia e delle finanze dal decreto legislativo 30 luglio 1999, n. 300, e dal decreto legislativo 31 marzo 1998, n. 143, e adeguamento delle disposizioni legislative che regolano i singoli enti al quadro delle competenze delineato dal medesimo decreto legislativo n. 143 del 1998, nonche' all'assetto costituzionale derivante dalla legge costituzionale 18 ottobre 2001, n. 3;
- b) riassetto organizzativo degli enti operanti nel settore dell'internazionalizzazione delle imprese, secondo principi ispirati alla maggiore funzionalita' dei medesimi in relazione alle rinnovate esigenze imposte dall'attuale quadro economico-finanziario, nonche' ad obiettivi di coerenza della politica economica e commerciale estera e della promozione del sistema economico italiano in ambito internazionale con le funzioni svolte dall'Amministrazione centrale degli affari esteri, dalle rappresentanze diplomatiche e dagli uffici consolari in materia di rappresentanza, di coordinamento e di tutela degli interessi italiani in sede internazionale;
- c) razionalizzazione delle relative norme di natura finanziaria ed economica, anche al fine di realizzare risparmi di spesa idonei a reperire le risorse necessarie per la copertura degli oneri derivanti dall'istituzione e dal funzionamento degli sportelli unici all'estero, in particolare ai fini della promozione del made in Italy e della lotta alle contraffazioni;
- d) possibilita' di attivazione di strumenti di finanziamento di investimenti all'estero anche tramite societa' prevedendo, tra l'altro, che il fondo di cui all'articolo 5, comma 2, lettera c), della legge 21 marzo 2001, n. 84, e tutti i fondi rotativi gestiti dalla SIMEST Spa, destinati ad operazioni di venture capital in Paesi non aderenti all'Unione europea, siano unificati in un unico fondo e disciplinati in analogia ai fondi mobiliari chiusi;
- e) compatibilita' con gli obiettivi di riassetto della normativa in materia di internazionalizzazione di cui al comma 1.

1-quater. Ciascuno degli schemi di decreti legislativi di cui al comma 1-bis deve essere corredato di relazione tecnica sugli effetti finanziari delle disposizioni in esso contenute, ai sensi dell'articolo 11-ter, comma 2, della legge 5 agosto 1978, n. 468, e successive modificazioni, la quale deve altresi' precisare gli effetti finanziari della razionalizzazione di cui al comma 1-ter, lettera c), del presente articolo individuando le risorse derivanti dai correlati risparmi e finalizzate all'istituzione e al funzionamento degli sportelli unici all'estero, in particolare ai fini della promozione del made in Italy e della lotta alle contraffazioni. I suddetti schemi di decreti legislativi sono adottati, d'intesa con la Conferenza permanente per i rapporti tra lo Stato, le regioni e le province autonome di Trento e di Bolzano, su proposta del Ministro delle attivita' produttive, di concerto con i Ministri degli affari esteri, dell'economia e delle finanze, per la funzione pubblica, per le politiche comunitarie e per gli italiani nel Mondo, e sono trasmessi al Parlamento, ai fini dell'espressione dei pareri da parte delle Commissioni parlamentari competenti per materia e per le conseguenze di carattere finanziario entro il termine di sessanta giorni dalla data di trasmissione; decorso inutilmente tale termine, i decreti possono comunque essere emanati. Qualora detto termine venga a scadere nei trenta giorni antecedenti alla scadenza del termine previsto dal comma 1-bis o successivamente, la scadenza di quest'ultimo e' prorogata di novanta giorni.

1-quinquies. Entro un anno dalla data di entrata in vigore dei decreti legislativi di cui al comma 1-bis, il Governo puo' emanare disposizioni correttive e integrative, nel rispetto dei principi e criteri direttivi di cui al comma 1-ter e con la procedura di cui al comma 1-quater

))

### Art. 10. - Riassetto in materia di societa' dell'informazione

1. Il Governo e' delegato ad adottare, entro diciotto mesi dalla data in entrata in vigore della presente legge, uno o piu' decreti legislativi, su proposta del Ministro per l'innovazione e le tecnologie e dei Ministri competenti per materia, per il coordinamento e il riassetto delle disposizioni vigenti in materia di societa' dell'informazione, ai sensi e secondo i principi e i criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) graduare la rilevanza giuridica e l'efficacia probatoria dei diversi tipi di firma elettronica in relazione al tipo di utilizzo e al grado di sicurezza della firma;
- b) rivedere la disciplina vigente al fine precipuo di garantire la piu' ampia disponibilita' di servizi resi per via telematica dalle pubbliche amministrazioni e dagli altri soggetti pubblici e di assicurare ai cittadini e alle imprese l'accesso a tali servizi secondo il criterio della massima semplificazione degli strumenti e delle procedure necessari e nel rispetto dei principi di eguaglianza, non discriminazione e della normativa sulla riservatezza dei dati personali;
- c) prevedere la possibilita' di attribuire al dato e al documento informatico contenuto nei sistemi informativi pubblici i caratteri della primarieta' e originalita', in sostituzione o in aggiunta a dati e documenti non informatici, nonche' obbligare le amministrazioni che li detengono ad adottare misure organizzative e tecniche volte ad assicurare l'esattezza, la sicurezza e la qualita' del relativo contenuto informativo;
- d) realizzare il coordinamento formale del testo delle disposizioni vigenti, apportando, nei limiti di detto coordinamento, le modifiche necessarie per garantire la coerenza logica e sistematica della normativa anche al fine di adeguare o semplificare il linguaggio normativo;
- e) adeguare la normativa alle disposizioni comunitarie.

2. La delega di cui al comma 1 e' esercitata per i seguenti oggetti:

- a) il documento informatico, la firma elettronica e la firma digitale;
- b) i procedimenti amministrativi informatici di competenza delle amministrazioni statali anche ad ordinamento autonomo;
- c) la gestione dei documenti informatici;
- d) la sicurezza informatica dei dati e dei sistemi;
- e) le modalita' di accesso informatico ai documenti e alle banche dati di competenza delle amministrazioni statali anche ad ordinamento autonomo.

3. Il Governo e' delegato ad adottare uno o piu' decreti legislativi recanti disposizioni correttive e integrative dei decreti legislativi di cui al comma 1, nel rispetto degli oggetti e dei principi e criteri direttivi determinati dal presente articolo, entro (( quindici mesi )) decorrenti dalla data di scadenza del termine di cui al medesimo comma 1.

### Art. 11. - Riassetto delle disposizioni relative al Corpo nazionale dei vigili del fuoco

1. Il Governo e' delegato ad adottare, (( entro trenta mesi )) dalla data di entrata in vigore della presente legge, uno o piu' decreti legislativi per il riassetto delle disposizioni vigenti concernenti il Corpo nazionale dei vigili del fuoco, ai sensi e secondo i principi e i criteri direttivi di cui all'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, e nel rispetto dei seguenti principi e criteri direttivi:

- a) revisione e riassetto della normativa che disciplina le funzioni e i compiti del Corpo nazionale dei vigili del fuoco in materia di soccorso pubblico, prevenzione incendi, protezione civile, difesa civile e incendi boschivi, nonche' l'ordinamento del personale per gli aspetti non demandati alla contrattazione collettiva nazionale, in modo da consentirne la coerenza giuridica, logica e sistematica, con particolare riferimento: 1) alla definizione delle attribuzioni del Corpo nazionale dei vigili del fuoco negli interventi di soccorso pubblico; 2) al riassetto della normativa in materia di prevenzione incendi e di vigilanza antincendi, tenuto conto anche dell'evoluzione tecnologica e dei mutamenti socio-ambientali; 3) alla revisione delle disposizioni sui poteri autorizzatori in materia di prevenzione incendi e di vigilanza antincendi;
- b) armonizzazione delle disposizioni sulla prevenzione incendi alla normativa sullo sportello unico per le attivita' produttive;
- c) coordinamento e adeguamento della normativa alle disposizioni comunitarie e agli accordi internazionali.

2. All'attuazione ed esecuzione delle disposizioni emanate ai sensi del comma 1 si provvede con uno o piu' regolamenti, da emanare ai sensi dell'articolo 17, commi 1 e 3, della legge 23 agosto 1988, n. 400, e successive modificazioni, entro dodici mesi dalla data di entrata in vigore dei decreti legislativi di cui al citato comma 1.

## DISPOSIZIONI IN MATERIA DI ANALISI DI IMPATTO DELLA REGOLAMENTAZIONE E DI ATTI NORMATIVI GOVERNATIVI. DISPOSIZIONI IN MATERIA DI PUBBLICO IMPIEGO

### Art. 12. - (Analisi di impatto delle funzioni di vigilanza e regolazione delle autorita' amministrative indipendenti).

1. Le autorita' amministrative indipendenti, cui la normativa attribuisce funzioni di controllo, di vigilanza o regolatorie, si dotano, nei modi previsti dai rispettivi ordinamenti, di forme o metodi di analisi dell'impatto della regolamentazione per l'emanazione di atti di competenza e, in particolare, di atti amministrativi generali, di programmazione o pianificazione, e, comunque, di regolazione.

2. Le autorita' di cui al comma 1 trasmettono al Parlamento le relazioni di analisi di impatto della regolamentazione da loro realizzate.

3. I soggetti di cui al comma 1 provvedono alla verifica degli effetti derivanti dall'applicazione di contratti predisposti mediante moduli o formulari ovvero di clausole e condizioni contrattuali normativamente previste o a contenuto generale.

4. Sono, comunque, escluse dall'applicazione del presente articolo le segnalazioni e le altre attivita' consultive, anche se concernenti gli atti di cui al comma 1, nonche' i procedimenti previsti dalla legge 10 ottobre 1990, n. 287, e successive modificazioni.

### Art. 13. - (Disposizioni relative all'attivita' della Corte dei conti e all'accesso alla magistratura della Corte dei conti).

1. Il parere della Corte dei conti, previsto dall'articolo 88 del regio decreto 18 novembre 1923, n. 2440, sugli schemi di atti normativi del Governo, e' reso nel termine di quarantacinque giorni dal ricevimento della richiesta; decorso tale termine, si procede indipendentemente dall'acquisizione del parere. Qualora, per esigenze istruttorie, non possa essere rispettato il termine di cui al presente comma, tale termine puo' essere interrotto per una volta e il parere deve essere reso definitivamente entro venti giorni dal ricevimento degli elementi istruttori da parte delle amministrazioni interessate.

2. All'articolo 11-ter, comma 6, della legge 5 agosto 1978, n. 468, dopo il primo periodo e' aggiunto il seguente: "La Corte riferisce, inoltre, su richiesta delle Commissioni parlamentari competenti nelle modalita' previste dai Regolamenti parlamentari, sulla congruenza tra le conseguenze finanziarie dei decreti legislativi e le norme di copertura recate dalla legge di delega".

3. All'articolo 12, primo comma, della legge 20 dicembre 1961, n. 1345, la lettera d) e' sostituita dalla seguente: "d) gli avvocati iscritti nel relativo albo professionale da almeno cinque anni".

4. All'articolo 12, primo comma, lettera e), della legge 20 dicembre 1961, n. 1345, come modificata dall'articolo 3, comma 8, della legge 15 maggio 1997, n. 127, al primo periodo, le parole: "Amministrazioni dello Stato" sono sostituite dalle seguenti: "Amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165"; il secondo periodo e' sostituito dal seguente: "I bandi di concorso possono riservare una percentuale non inferiore al 20 per cento dei posti messi a concorso a personale che sia dotato oltre che del diploma di laurea in giurisprudenza, anche del diploma di laurea in scienze economico-aziendali o in scienze dell'economia o di altro titolo di studio equipollente".

5. Una quota non inferiore al 20 per cento della dotazione organica del personale della carriera dirigenziale e direttiva in servizio presso la Corte dei conti e' riservata ai laureati in discipline economiche o statistiche o attuariali.

### Art. 14. - (Modifiche al decreto legislativo 30 marzo 2001, n. 165).

1. Al comma 2, primo periodo, dell'articolo 28 del decreto legislativo 30 marzo 2001, n. 165, come sostituito dall'articolo 3 della legge 15 luglio 2002, n. 145, dopo le parole: "almeno cinque anni di servizio", sono inserite le seguenti: "o, se in possesso del diploma di specializzazione conseguito presso le scuole di specializzazione individuate con decreto del Presidente del Consiglio dei ministri, di concerto con il Ministro dell'istruzione, dell'universita' e della ricerca, almeno tre anni di servizio".

2. Al comma 2, ultimo periodo, dell'articolo 40 del decreto legislativo 30 marzo 2001, n. 165, come modificato dall'articolo 7 della legge 15 luglio 2002, n. 145, la parola: "oppure" e' sostituita dalle seguenti: "e per gli archeologi e gli storici dell'arte aventi il requisito di cui all'articolo 1, comma 3, della legge 7 luglio 1988, n. 254, nonche' per gli archivisti di Stato, i bibliotecari e gli esperti di cui all'articolo 2, comma 1, della medesima legge, che, in posizione di elevata responsabilita', svolgono compiti".

### Art. 15. - (Modifica all'articolo 38 della legge 23 dicembre 1999, n. 488).

1. All'articolo 38 della legge 23 dicembre 1999, n. 488, il comma 3 e' sostituito dal seguente: "3. I lavoratori dipendenti di cui al comma 1, qualora intendano avvalersi della facolta' di accreditamento dei contributi di cui al medesimo comma 1, presentano domanda entro il 30 settembre dell'anno successivo a quello nel corso del quale ha avuto inizio l'aspettativa, a pena di decadenza. La domanda si intende tacitamente rinnovata ogni anno salvo espressa manifestazione di volonta' in senso contrario".

## MISURE TELEMATICHE

### Art. 16.

(( ARTICOLO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82 ))

### Art. 17.

(( ARTICOLO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82 ))

### Art. 18.

(( ARTICOLO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82 ))

### Art. 19.

(( ARTICOLO ABROGATO DAL D.LGS. 7 MARZO 2005, N. 82 ))

## DISPOSIZIONI TRANSITORIE E FINALI

### Art. 20. - (Norme transitorie).

1. Per la legge per la semplificazione e il riassetto normativo dell'anno 2003 i termini di cui al comma 1 dell'articolo 20 della legge 15 marzo 1997, n. 59, come sostituito dall'articolo 1 della presente legge, sono rispettivamente fissati al novantesimo e al centoventesimo giorno dalla data di entrata in vigore della presente legge.

### Art. 20-bis. - (Decreti legislativi correttivi e integrativi)

1. Entro un anno dalla data di entrata in vigore dei decreti legislativi di cui agli articoli 2,3,4,5,6,7,8,9 e 11, il Governo puo' adottare, nel rispetto degli oggetti e dei principi e criteri direttivi fissati dalla presente legge e secondo i principi e i criteri direttivi e la procedura di cui all'articolo 20 della legge 15 marzo 1997, n. 59, e successive modificazioni, uno o piu' decreti legislativi recanti disposizioni integrative e correttive. (8) ((9))

--------------- AGGIORNAMENTO (8) La L. 12 luglio 2006, n. 228 ha disposto (con l'art. 1, comma 14) che "E' prorogato di un anno il termine di cui al comma 1 dell'articolo 20-bis della legge 29 luglio 2003, n. 229, per l'adozione di uno o piu' decreti legislativi recanti disposizioni integrative e correttive dei decreti legislativi di cui agli articoli 4 e 7 della citata legge 29 luglio 2003, n. 229, nel rispetto degli oggetti, dei principi e criteri direttivi e della procedura di cui al medesimo articolo 20-bis." --------------- AGGIORNAMENTO (9) La L. 26 febbraio 2007, n. 17 (con l'art. 1, comma 2) ha disposto che "Il termine di un anno previsto dall'articolo 20-bis, comma 1, della legge 29 luglio 2003, n. 229, per l'adozione di decreti legislativi integrativi e correttivi del decreto legislativo di cui all'articolo 11 della medesima legge, e' prorogato di un anno."

### Art. 21. - (Copertura finanziaria).

1. Dall'esercizio di ciascuna delle deleghe di cui al Capo I non devono derivare maggiori oneri a carico del bilancio dello Stato.

2. All'onere derivante dall'attuazione dell'articolo 16, determinato nella misura massima di 516.457 euro a decorrere dall'anno 2003, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2003-2005, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2003, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

3. All'onere derivante dall'attuazione dell'articolo 17, determinato nella misura massima di 324.850 euro per l'anno 2003 ed in 141.510 euro annui a decorrere dall'anno 2004, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2003-2005, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2003, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero.

4. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

### Art. 22. - (Modifiche alla legge 24 novembre 2000, n. 340).

1. L'articolo 35 della legge 24 novembre 2000, n. 340, e' sostituito dal seguente: "ART. 35. (Controversie in materia di masi chiusi). 1. In tutte le controversie in materia di masi chiusi concernenti la determinazione dell'assuntore del maso chiuso e la determinazione del prezzo di assunzione si osservano le disposizioni dettate dal capo I del titolo IV del libro secondo del codice di procedura civile. Il tentativo di conciliazione previsto dall'articolo 410 del codice di procedura civile e' esperito dinanzi alla Ripartizione agricoltura della provincia autonoma di Bolzano. 2. Chi intende proporre in giudizio una domanda relativa all'ordinamento dei masi chiusi e' tenuto ad esperire il tentativo di conciliazione ai sensi dell'articolo 46 della legge 3 maggio 1982, n. 203, in cui la Ripartizione agricoltura della provincia autonoma di Bolzano si intende sostituita all'ispettorato provinciale dell'agricoltura. 3. Tutti gli atti, i documenti e i provvedimenti relativi ai procedimenti, anche esecutivi, cautelari e tavolari relativi alle controversie in materia di masi chiusi, sono esenti dall'imposta di bollo, di registro, da ogni altra tassa e dal contributo unificato".

2. All'onere derivante dall'attuazione del comma 3 dell'articolo 35 della legge 24 novembre 2000, n. 340, come sostituito dal comma 1 del presente articolo, valutato in 15.000 euro annui a decorrere dall'anno 2003, si provvede mediante corrispondente riduzione dello stanziamento iscritto, ai fini del bilancio triennale 2003-2005, nell'ambito dell'unita' previsionale di base di parte corrente "Fondo speciale" dello stato di previsione del Ministero dell'economia e delle finanze per l'anno 2003, allo scopo parzialmente utilizzando l'accantonamento relativo al medesimo Ministero. Il Ministro dell'economia e delle finanze e' autorizzato ad apportare, con propri decreti, le occorrenti variazioni di bilancio.

3. Alla legge 24 novembre 2000, n. 340, nell'allegato A, il numero 43 e' sostituito dal seguente: "43. Procedimenti relativi all'acquisto e alla locazione di nuove macchine utensili o di produzione. Legge 28 novembre 1965, n. 1329".

4. Alla legge 24 novembre 2000, n. 340, nell'allegato A, dopo il numero 63, sono aggiunti i seguenti: "63-bis. Procedimento di astensione anticipata dal lavoro delle donne in stato di gravidanza. Testo unico delle disposizioni legislative in materia di tutela e sostegno della maternita' e della paternita', di cui al decreto legislativo 26 marzo 2001, n. 151, articolo 17, commi 2 e 3. 63-ter. Procedimento di predisposizione ed approvazione dei regolamenti interni degli istituti penitenziari e delle relative modifiche. Legge 26 luglio 1975, n. 354, articolo 16; Decreto legislativo 30 ottobre 1992, n. 444, articolo 10".

### Art. 23. - (Abrogazioni).

1. A decorrere dalla data di entrata in vigore della presente legge, la legge 10 marzo 1969, n. 116, e' abrogata.

2. A decorrere dalla data di entrata in vigore della presente legge sono abrogati i commi 13-ter, 13-quater e 13-quinquies dell'articolo 3 del decreto-legge 27 aprile 1990, n. 90, convertito, con modificazioni, dalla legge 26 giugno 1990, n. 165. Gli atti privi della dichiarazione ivi prevista sono sanati con efficacia retroattiva fermo il diritto maturato da terzi in base ad atto trascritto anteriormente alla data di entrata in vigore della presente legge.

3. A decorrere dalla data di entrata in vigore della presente legge e' abrogato l'articolo 7 della legge 8 marzo 1999, n. 50. Le procedure avviate ai sensi del citato articolo 7 per le quali, alla data di entrata in vigore della presente legge, sia intervenuta la richiesta di parere al Consiglio di Stato, possono essere completate con l'emanazione dei previsti testi unici entro centoventi giorni dalla data di entrata in vigore della presente legge.

4. A decorrere dalla data di entrata in vigore della presente legge, alla legge 24 novembre 2000, n. 340, all'articolo 1, comma 4, sono abrogate le lettere g), h) ed i). A decorrere dalla medesima data, riacquistano efficacia le previsioni di cui ai numeri 94, 97 e 98 dell'allegato 1 alla legge 15 marzo 1997, n. 59, nel testo vigente prima della data di entrata in vigore della citata legge n. 340 del 2000.

5. All'allegato 1 della legge 15 marzo 1997, n. 59, e successive modificazioni, sono soppresse le previsioni di cui ai numeri 10, 12, 25, 28, 29, 32, 33, 34, 36, 41, 58, 68, 74, 98-bis, 99, 106, 112-ter, 112-quater e 112-octies.

6. All'allegato 1 della legge 8 marzo 1999, n. 50, e successive modificazioni, sono soppresse le previsioni di cui ai numeri 17, 22, 38, 39 e 44.

7. All'allegato A della legge 24 novembre 2000, n. 340, sono soppresse le previsioni di cui ai numeri 2, 4, 7, 13, 25, 31, 33, 34, 35, 36, 37, 38, 40, 41, 56, 57, 59 e 60.

